<?php

/**
 * Provides a link to the CSS stylesheet associated with this module.
 *
 * @return a &lt;style&gt; tag that indicates what file browsers should import
 */
function ejournal_html_head() {
	drupal_add_css(drupal_get_path('module', 'ejournal') . '/ejournal.css');
	//TODO let plugins do their stuff
	return "";
}

/** 
* theme_ejournal_page: Display the page.
*
* @param $journal
*   A journal object
* @param $output
*   A journal's body content
*/


function theme_ejournal_page($journal = NULL, $output = NULL) {
  drupal_set_html_head(ejournal_html_head());
  return theme('page', $output ? $output : $journal);
}


/** 
* theme_ejournal_list_all_journals: A themeable function that lists all of the journals on the site.
*
* @return
*   An HTML-formatted display showing the name of each journal and its description.
*/

function theme_ejournal_list_all_journals($action='show') {
  $result = db_query("SELECT * FROM {ejournal_journals} WHERE enabled='1'");
  
  while ($journal = db_fetch_object($result)) {
    $output .= ejournal_theme('ejournal_journal_reference', $journal, $action);
  }  
  drupal_set_title(t('Journals'));
  return ejournal_theme('ejournal_page', $journal, "<div class=\"ejournal\">$output</div>");
}

function theme_ejournal_display_issue($journal, $iid, $print = FALSE) {
  global $ejrn_viewed_issue;
  
  $order = variable_get('ejournal_issue_order', 'DESC');
  $issue = ejournal_issue_get($iid);
  
  //ejrn_viewed_issue is a special variable used in themes to display identification of the
  //current (displayed) issue, it may be shown in the header of the whole site
  $ejrn_viewed_issue = $issue;
  
  $output = ejournal_theme('ejournal_journal_reference', $journal);
  $issue = ejournal_issue_get($iid);
  if ($issue->cover_page_nid) {
    $output .= '<div class="coverpage journal' . $journal->jid . '">';
    $output .= node_view(node_load($issue->cover_page_nid));
    $output .= '</div>'; 
  }
  $result = _ejournal_issue_get_articles($journal, $iid);
  
  if ($print && $iid) { // we will print contents of the whole issue (should we allow it?)
    $out = "<html><head>";  //TODO, this sucks
    $out .= drupal_get_html_head();
    $out .= "</head><body>";
    foreach ($result as $article) {
      $out .= node_view(node_load(array (
        'nid' => $article->nid
        )));
      $out .= "\n<hr/><hr/>";
    }
    $out .= "\n</body></html>";
    return $out;
  }
  
  $old_section = "";
  foreach ($result as $article) {
    if ($article->name != $old_section) {
      $output .= ejournal_theme('ejournal_section', $journal, $article->name);
      $old_section = $article->name;
    }			
    $output .= ejournal_theme('ejournal_plugins', ejournal_invoke_extensions('display_issue', $journal, $issue, $article));
    $output .= ejournal_theme('ejournal_article_reference', $journal, $article) . "<br/>";
  }
  
  drupal_set_title(t('%title %issue', array (
    '%title' => $journal->title,
    '%issue' => ejournal_issue_reference($issue,
			$journal
      ))));
  return $output;
}

function theme_ejournal_journal_reference($journal, $action='show') {
  $path = ejournal_path_set(array('action' => $action, 'jid' => $journal->jid));
  $output .= '<div class="ejournal" id="ejournal-' . $journal->jid . '">' . l($journal->title, $path) . "<br/>\n";
  if ($journal->description) {
    $output .= "<p>$journal->description</p>\n";
  }
  $output .= "</div>\n";  
  return $output;
}

function theme_ejournal_volume_reference($journal, $issue, $jid = FALSE) {
  if($jid) {
    $path = ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'vid' => 'v' . urlencode($issue->volume)));
    $out = l(ejournal_volume_reference($issue), $path);
  }
  else {
    $out = ejournal_volume_reference($issue);
  }
  return "<div class=\"volume\">" . $out . "</div>\n";
}


/** 
* theme_ejournal_issue_reference: A themeable layout that formats a single issue of a journal.
*
* @param $issue
*   An edition object.
*
* @return
*   An HTML-formatted display showing the reference name of the issue
*/

function theme_ejournal_issue_reference($journal, $issue, $full = TRUE) {  
  $output = "<div class=\"issue\">";
  if ($full) {
    $output .= l((ejournal_issue_reference($issue)), ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'iid' => $issue->iid)));
  } else {
    $path = ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'iid' => $issue->iid));
    $visible = isset($issue->number) ? t('No. ') . $issue->number : $issue->custom;
    $output .= l($visible, $path);
    $output .= "<br/>[ " . format_date($issue->date_published, 'custom', 'd. m. Y') . " ]";
  }
  $output .= "</div>\n";
  return $output;
}

function theme_ejournal_article_reference($journal, &$article) {  
  return l($article->title, "node/$article->nid", array ('class' => 'article'));
}

function theme_ejournal_section($journal, $section) {
  return "<div class=\"section\">$section</div>\n";
}

function theme_ejournal_archive($journal, $issues = NULL) {
  
  if (!$issues) { // if no issues, we will display whole archive
    $issues = _ejournal_journal_get_issues($journal);
    $full_archive = 1;
  }
  $output = "<div class=\"archive\">\n";  
  $output .= "<div>";
  
  while ($issue = db_fetch_object($issues)) {
    if ($issue->volume != $old_volume) {
      $output .= "</div><div>";
      $output .= $full_archive ? ejournal_theme('ejournal_volume_reference', $journal, $issue) : ejournal_theme('ejournal_volume_reference', $journal, $issue);
      $old_volume = $issue->volume;
    }
    $output .= ejournal_theme('ejournal_issue_reference', $journal, $issue, FALSE);
    
    if (!$full_archive) {
      $articles = _ejournal_issue_get_articles($journal, $issue->iid);
      foreach ($articles as $article) {
        $output .= l($article->title, "node/$article->nid") . "<br/>";
      }
    }
  }
  $output .= "</div>";
  
  if ($full_archive && $journal->vid) {
    $output .= "<div class=\"section-form\"><h3>" . t('Display articles in section') . "</h3>\n";			
    $output .= drupal_get_form('theme_ejournal_section_form', $journal);
    $output .= "</div>";
  }
  $output .= "</div>";
  drupal_set_title(t('%journal archive', array ('%journal' => $journal->title)));
  
  return ejournal_theme('ejournal_page', $journal, $output);
}


function theme_ejournal_section_form($journal) {
	$form = array ();
	$form['tid'] = array (
		'#type' => 'select',
		'#title' => t('Section'), 
    '#default_value' => NULL, 
    '#options' => ejournal_sections_get($journal->jid, NULL)
    );
	$form['jid'] = array (
		'#type' => 'hidden',
		'#value' => $journal->jid
    );
	$form['op'] = array (
		'#type' => 'submit',
		'#value' => t('Submit'));
	$form['#action'] = url(ejournal_path_set(array('action' => 'term', 'jid' => $journal->jid)));
	return  $form;
}

function theme_ejournal_about($journal) {
  if ($journal->about_page) {
    print ejournal_theme('ejournal_page', $journal, node_view(node_load($journal->about_page)));
  }
  else  {
    print ejournal_theme('ejournal_archive', $journal);
  }
}

/**
* This is only call to taxonomy_term_page function
**/
function theme_ejournal_taxonomy_term_page($journal, $str_tids = '', $depth = 0, $op = 'page') {
  //blessed we are, developers gave us chance to override the links!
  //ejournal_link_alter hook
  return ejournal_theme('ejournal_page', $journal, taxonomy_term_page($str_tids, $depth, $op));
}

function theme_ejournal_list_vocabulary($journal, $vid, $char = NULL) {
  if (!is_numeric($vid)) {
    return;
  }
  /*
  $list = db_query("SELECT LEFT(name, 1) AS x FROM {term_data} WHERE vid='%d' GROUP BY x", $vid);
  while($char = db_fetch_object($list)) {
  $chars[] = l($char->x, "ejournal/$journal->jid/list/$vid/" . urlencode($char->x));
  }
  $output = implode(' ', $chars);
  */
  
  //select term together with synonyms (if any) - group by name and show duplicates in "num"
  $sql = "(SELECT tid, name, COUNT(name) AS num FROM {term_data} WHERE vid=$vid GROUP BY name) UNION ALL (SELECT ts.tid, ts.name, 0 AS num FROM {term_synonym} ts INNER JOIN {term_data} td ON ts.tid=td.tid WHERE td.vid=$vid GROUP BY ts.name) ORDER BY name";
  
  //$sql = "SELECT name, tid FROM {term_data} WHERE vid='".db_escape_string($vid)."' ORDER BY name";
  $sql_count = "SELECT count(name) FROM {term_data} WHERE vid='" . db_escape_string($vid) . "'";
  $result = pager_query($sql, 50, 0, $sql_count);
  
  $path = ejournal_path_get();
  $path['action'] = 'term';
  $path['jid'] = $journal->jid;
  $path['vid'] = $vid;
  ejournal_invoke_extensions('register_path', $path);
  
  $i = 0;
  $output .= theme('pager', NULL, 50, 0);
  $output .= "<div class=\"ejournal-list\">\n";
  while ($term = db_fetch_object($result)) {
    $new_path = ejournal_path_set(array('base' => $path['base'], 'action' => $path['action'], 'jid' => $path['jid'], 'iid' => $term->tid));
    if ($term->num) {
      if ($term->num > 1) { // two terms with identical name
        $output .= l("$term->name *", $new_path, NULL, urlencode("edit[multiple]") . "=1") . "<br/>\n";
      } else {
        $output .= l($term->name, $new_path, NULL) . "<br/>\n";
      }
    } else {
      $output .= $term->name . ' &nbsp;' . l(t('see this'), $path, NULL, $url_type) . "<br/>\n";
    }
    $i++;
    if ($i == 25) {
      $output .= "</div><div class=\"ejournal-list\">";
      $i = 0;
    }
  }
  $output .= "</div>\n";
  
  $output .= theme('pager', NULL, 50, 0);
  drupal_set_title(t('Browse journal %name', array (
    '%name' => $journal->title
		)));
  return ejournal_theme('ejournal_page', $journal, $output);
}

function theme_ejournal_list_vocabularies($journal) {
    
  $vocs = taxonomy_get_vocabularies();
  foreach ((array)$journal as $key => $value) {
    if(strpos($key, 'vid') !== false) {
      foreach (split(',', ($value)) as $vid) {
        
        $path = ejournal_path_get();
        $path['action'] = 'browse';
        $path['jid'] = $journal->jid;
        $path['vid'] = $vid;
        ejournal_invoke_extensions('register_path', $path);

        if ($vocs[$vid]) {
          $new_path = ejournal_path_set($path);
          $output .= "<h3>" . l($vocs[$vid]->name, $new_path) . "</h3>";
          $output .= '<p>' . $vocs[$vid]->description . "</p>\n";
          unset ($vocs[$vid]);
        }
      }
    }
  }
  drupal_set_title(t('Browse journal %name', array ('%name' => $journal->title)));
  print ejournal_theme('ejournal_page', $journal, $output);
}

function theme_ejournal_plugins($journal, $plugins = array()) {
  return implode("\n", $plugins);
}

?>
